
History
=======

1.1
---

- adopt to yafowil 1.2
  [jensens, 2011-09-20]

- make ready for z2c.autoinclude+Plone (only if available).
  [jensens, 2011-09-20]

1.0
---

- add display renderer
  [rnix, 2011-08-03]

- adopt to yafowil 1.1
  [rnix, 2011-07-08]

0.9.1
-----

- test coverage
  [rnix, 2011-05-07]

0.9
---

- made it work [rnix]
